@@ -15,14 +15,14 @@ use Carp;
 
 requires 'submit';
 
-our $VERSION = '1.0.3'; # VERSION
+our $VERSION = '1.0.4'; # VERSION
 # ABSTRACT: Contact API Calls
 
 sub create_contact {
     my $self   = shift;
     my (%args) = validated_hash(
         \@_,
-        contact => { isa => Contact },
+        contact => { isa => Contact, coerce => 1 },
     );
 
     if( $args{contact}->has_id ) {
